ImagePickerMasterWeb class
A stub implementation of ImagePickerMasterPlatform for non-web platforms.
- Inheritance
-
- Object
- PlatformInterface
- ImagePickerMasterPlatform
- ImagePickerMasterWeb
Constructors
- ImagePickerMasterWeb()
- Creates a new instance of ImagePickerMasterWeb.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
capturePhoto(
{required bool allowCompression, required int compressionQuality, required bool withData}) → Future< PickedFile?> -
Captures a photo using the device camera.
override
-
clearTemporaryFiles(
) → Future< void> -
Clears all temporary files created by the plugin.
override
-
cropImageNative(
{required String path, required double cropX, required double cropY, required double cropW, required double cropH, required double containerW, required double containerH, int rotation = 0, int quality = 85, String format = 'jpeg', int maxSize = 1200}) → Future< String?> -
Crops an image natively without going through a Dart isolate.
override
-
getPlatformVersion(
) → Future< String?> -
Returns the platform version string.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pickFiles(
FilePickerOptions options) → Future< List< PickedFile> ?> -
Picks files from the device storage based on the provided options.
override
-
resizeImageForCropper(
{required String path, int maxSize = 1024}) → Future< String?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
registerWith(
dynamic registrar) → void - Registers this class as the default instance of ImagePickerMasterPlatform.